Use Case: Become A Site Member
==============================

Actor
-----

Site Visitor

Overview
--------

Becoming a member of a site allows you to access the additional services of
the site. Often this includes a personal online work area (your "desktop"),
the ability create and submit your own content for publication and the
ability to personalize the look and behavior of the site to better meet your
needs.

Note that different sites have different purposes, and the specific services
available to site members depends on the choices of the site administrators.
By default, a CMF site provides members with a private "desktop", the ability
to create certain types of basic content and the ability to select the visual
style of the site that they see.

Procedure
---------

1. To become a member of a site, visit the site homepage and click on the
   "Join" link in the menu located on the left side of the page.

2. Clicking the "Join" link will take you to a form. Complete the fields on
   the form and click the "Register" button to become a registered member of the
   site.

3. The exact information required by the registration form will vary from
   site to site. The form for a default CMF site requires visitors to provide at
   least a login name, a password and a valid email address to become a member.
   The default form also gives you an option to have the password you provided
   at registration time emailed to you for future reference.

4. After submitting the member registration form, you should see a page
   informing you that you have successfully been registered as a site member.
   This page also provides a link that you can use to log into the site
   immediately.
